@@ -34,15 +34,15 @@
 #include "eggtrayicon.h"
 
 #include "acme.h"
-#include "g-volume.h"
+#include "acme-volume.h"
 #ifdef USE_FBLEVEL
-#include "fb-level.h"
+#include "acme-fb-level.h"
 #endif
 
 typedef struct {
-	GVolume *volobj;
+	AcmeVolume *volobj;
 #ifdef USE_FBLEVEL
-	FBLevel *levobj;
+	AcmeFblevel *levobj;
 #endif
 	GladeXML *xml;
 	GtkWidget *dialog;
@@ -224,25 +224,13 @@ permission_problem_string (const char *files)
 				"the problem and restart ACME."), files);
 }
 
-static gboolean
-vol_problem_cb (GVolume *fb, gpointer data)
-{
-	char *msg;
-
-	msg = permission_problem_string ("/dev/mixer");
-	acme_error (msg);
-	g_free (msg);
-
-	return TRUE;
-}
-
 #ifdef USE_FBLEVEL
 static void
 fb_problem_cb (void)
 {
 	char *msg;
 
-	if (fb_level_is_powerbook () == FALSE)
+	if (acme_fblevel_is_powerbook () == FALSE)
 		return;
 
 	msg = permission_problem_string ("/dev/pmu");
@@ -263,7 +251,7 @@ update_use_pcm_cb (GConfClient *client, guint id, GConfEntry *entry,
 	use_pcm = gconf_client_get_bool (acme->conf_client,
 			"/apps/acme/use_pcm",
 			NULL);
-	g_volume_set_use_pcm (acme->volobj, use_pcm);
+	acme_volume_set_use_pcm (acme->volobj, use_pcm);
 }
 
 static void
@@ -837,7 +825,7 @@ do_unknown_action (Acme *acme, const char *url)
 			"/desktop/gnome/url-handlers/unknown/command",
 			NULL);
 
-	if (string == NULL && strcmp (string, "") == 0)
+	if (string == NULL || strcmp (string, "") == 0)
 		return;
 
 	command = g_strdup_printf (string, url);
@@ -880,7 +868,7 @@ do_mail_action (Acme *acme)
 			"/desktop/gnome/url-handlers/mailto/command",
 			NULL);
 
-	if (string == NULL && strcmp (string, "") == 0)
+	if (string == NULL || strcmp (string, "") == 0)
 		return;
 
 	command = g_strdup_printf (string, "");
@@ -900,7 +888,7 @@ do_www_action (Acme *acme, const char *url)
 		"/desktop/gnome/url-handlers/http/command",
 		 NULL);
 
-	if (string == NULL && strcmp (string, "") == 0)
+	if (string == NULL || strcmp (string, "") == 0)
 	{
 		do_unknown_action (acme, url ? url : "");
 		return;
@@ -988,19 +976,19 @@ do_brightness_action (Acme *acme, int type)
 		acme->dialog_timeout = 0;
 	}
 
-	level = fb_level_get_level (acme->levobj);
+	level = acme_fblevel_get_level (acme->levobj);
 	acme_image_set (acme, ICON_BRIGHT);
 
 	switch (type) {
 	case BRIGHT_DOWN_KEY:
-		fb_level_set_level (acme->levobj, level - 1);
+		acme_fblevel_set_level (acme->levobj, level - 1);
 		break;
 	case BRIGHT_UP_KEY:
-		fb_level_set_level (acme->levobj, level + 1);
+		acme_fblevel_set_level (acme->levobj, level + 1);
 		break;
 	}
 
-	level = fb_level_get_level (acme->levobj);
+	level = acme_fblevel_get_level (acme->levobj);
 	progress = glade_xml_get_widget (acme->xml, "progressbar");
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress),
 			(double) level / 15);
@@ -1022,35 +1010,35 @@ do_sound_action (Acme *acme, int type)
 		acme->dialog_timeout = 0;
 	}
 
-	vol = g_volume_get_volume (acme->volobj);
-	muted = g_volume_get_mute (acme->volobj);
+	vol = acme_volume_get_volume (acme->volobj);
+	muted = acme_volume_get_mute (acme->volobj);
 
 	switch (type) {
 	case MUTE_KEY:
-		g_volume_mute_toggle(acme->volobj);
+		acme_volume_mute_toggle(acme->volobj);
 		break;
 	case VOLUME_DOWN_KEY:
 		if (muted)
 		{
-			g_volume_mute_toggle(acme->volobj);
+			acme_volume_mute_toggle(acme->volobj);
 		} else {
-			g_volume_set_volume (acme->volobj, vol - VOLUME_STEP);
+			acme_volume_set_volume (acme->volobj, vol - VOLUME_STEP);
 		}
 		break;
 	case VOLUME_UP_KEY:
 		if (muted)
 		{
-			g_volume_mute_toggle(acme->volobj);
+			acme_volume_mute_toggle(acme->volobj);
 		} else {
-			g_volume_set_volume (acme->volobj, vol + VOLUME_STEP);
+			acme_volume_set_volume (acme->volobj, vol + VOLUME_STEP);
 		}
 		break;
 	}
 
-	muted = g_volume_get_mute(acme->volobj);
+	muted = acme_volume_get_mute(acme->volobj);
 	acme_image_set (acme, muted ? ICON_MUTED : ICON_LOUD);
 
-	vol = g_volume_get_volume (acme->volobj);
+	vol = acme_volume_get_volume (acme->volobj);
 	progress = glade_xml_get_widget (acme->xml, "progressbar");
 	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (progress),
 			(double) vol / 100);
@@ -1154,9 +1142,6 @@ acme_filter_events (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 	GList *l;
 	int i;
 
-	if (xev->type != KeyRelease)
-		return GDK_FILTER_CONTINUE;
-
 	/* Look for which screen we're receiving events */
 	for (l = acme->screens; (l != NULL) && (event_screen == NULL);
 			l = l->next)
@@ -1193,6 +1178,19 @@ acme_filter_events (GdkXEvent *xevent, GdkEvent *event, gpointer data)
 			case NEXT_KEY:
 			case REFRESH_KEY:
 				return GDK_FILTER_CONTINUE;
+			case VOLUME_DOWN_KEY:
+			case VOLUME_UP_KEY:
+#ifdef USE_FBLEVEL
+			case BRIGHT_DOWN_KEY:
+			case BRIGHT_UP_KEY:
+#endif
+				/* auto-repeatable keys */
+				if (xev->type != KeyPress)
+					return GDK_FILTER_CONTINUE;
+				break;
+			default:
+				if (xev->type != KeyRelease)
+					return GDK_FILTER_CONTINUE;
 			}
 
 			acme->current_screen = event_screen;
@@ -1257,14 +1255,10 @@ main (int argc, char *argv[])
 	acme->dialog_timeout = 0;
 
 	/* initialise Volume handler */
-	acme->volobj = g_volume_new();
+	acme->volobj = acme_volume_new();
 	if (acme->volobj != NULL)
 	{
-		g_signal_connect(G_OBJECT(acme->volobj),
-				"fd_problem",
-				G_CALLBACK (vol_problem_cb), NULL);
-
-		g_volume_set_use_pcm (acme->volobj,
+		acme_volume_set_use_pcm (acme->volobj,
 				gconf_client_get_bool (acme->conf_client,
 					"/apps/acme/use_pcm", NULL));
 		gconf_client_notify_add (acme->conf_client,
@@ -1275,7 +1269,7 @@ main (int argc, char *argv[])
 
 #ifdef USE_FBLEVEL
 	/* initialise Frame Buffer level handler */
-	acme->levobj = fb_level_new();
+	acme->levobj = acme_fblevel_new();
 	if (acme->levobj == NULL)
 		fb_problem_cb ();
 #endif
